/**
 * Copyright (c) 2014-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.client.impl;

import java.util.Collections;
import java.util.Map;

import org.ow2.petals.registry.client.api.TopologyService;
import org.ow2.petals.registry.client.api.exception.UnexistingTopologyException;
import org.ow2.petals.registry_overlay.api.DataModelApi;
import org.ow2.petals.topology.generated.Topology;

import com.hazelcast.core.HazelcastInstance;

/**
 * Real implementation of {@link TopologyService}
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class TopologyServiceImpl implements TopologyService {

    private final HazelcastInstance hzlClient;

    public TopologyServiceImpl(final HazelcastInstance hzlClient) {
        this.hzlClient = hzlClient;
    }

    @Override
    public Map<String, Topology> getTopologies() {
        return Collections.unmodifiableMap(DataModelApi.getTopologiesMap(this.hzlClient));
    }

    @Override
    public Topology getTopology(final String topologyId) {
        return DataModelApi.getTopologiesMap(this.hzlClient).get(topologyId);
    }

    @Override
    public void clean(final String domain, final String subDomain) throws UnexistingTopologyException {
        try {
            DataModelApi.cleanTopology(this.hzlClient, DataModelApi.getRegistryName(domain, subDomain));
        } catch (final org.ow2.petals.registry_overlay.api.exception.UnexistingTopologyException e) {
            throw new UnexistingTopologyException(e.getTopologyId());
        }
    }

}
